#
# spec file for package lookbook
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define         appid com.github.danrabbit.lookbook
Name:           lookbook
Version:        1.2.0
Release:        2.4
Summary:        Navigator for finding and browsing system icons
License:        GPL-3.0-or-later
URL:            https://github.com/danrabbit/lookbook
Source:         %{url}/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  vala >= 0.40.4
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gobject-2.0)
BuildRequires:  pkgconfig(granite) >= 0.5
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(gtksourceview-4)
BuildRequires:  pkgconfig(libhandy-1) >= 1.0.0

%description
Lookbook is a browser for system icons. Icons can be grouped by
category or be searched by icon name. Icons are shown in different
sizes. A code snippet to use in programs can be displayed.

%lang_package

%prep
%autosetup

%build
%meson
%meson_build

%install
%meson_install
%find_lang %{appid}
%fdupes %{buildroot}

%files
%license COPYING
%doc README.md
%{_bindir}/%{appid}
%{_datadir}/applications/%{appid}.desktop
%{_datadir}/glib-2.0/schemas/%{appid}.gschema.xml
%{_datadir}/icons/hicolor/*/apps/%{appid}.svg
%{_datadir}/metainfo/%{appid}.appdata.xml
%dir %{_datadir}/icons/hicolor/{128x128@2,128x128@2/apps,16x16@2,16x16@2/apps,24x24@2,24x24@2/apps,32x32@2,32x32@2/apps,48x48@2,48x48@2/apps,64x64@2,64x64@2/apps}

%files lang -f %{appid}.lang

%changelog
* Mon Nov 18 2024 Richard Rahl <rrahl0@opensuse.org>
- update spec file for Leap 16.0:
  * remove %%suse_update_desktop_file
  * remove workaround for HiDPI images
  * use autosetup
  * remove recommending lang package
* Thu Sep  9 2021 Alexei Podvalsky <avvissu@yandex.by>
- Update to 1.2.0:
  * Add audio-headphones and audio-headset
  * Add distribute actions
  * Disable sidebar when searching
  * Remove non-fdo app names
  * Add status emblems
  * Mimetypes → Media Types
  * Added French and Portuguese translations
* Mon Oct 29 2018 Alexei Podvalsky <avvissu@yandex.by>
- Update to 1.1.0:
  * Add some symbolic view icons and fall back when color icons
    aren't available
  * Use ModeSwitch from Granite
  * Add credit cards icons (#39)
  * Focus search by default (#41)
  * Add "reload" to view-refresh description (#38)
* Wed Sep  5 2018 Jan Engelhardt <jengelh@inai.de>
- Use noun phrasing.
* Thu Aug 23 2018 avvissu@yandex.by
- Initial package
